﻿using System.Collections.Generic;

namespace Falcon.SugarApi.JWT
{
    /// <summary>
    /// 用户登录验证接口
    /// </summary>
    public interface IUserLogin
    {
        /// <summary>
        /// 登录是否成功
        /// </summary>
        /// <param name="login">登录凭据</param>
        /// <returns>成功返回用户信息，否则返回null</returns>
        LoginUserInfo? Login(LoginDto login);

        /// <summary>
        /// 用户登出
        /// </summary>
        /// <param name="userInfo">用户名</param>
        /// <returns>True成功，False失败</returns>
        bool LogOut(LoginUserInfo userInfo);

        /// <summary>
        /// 登录用户验证。检查客户端提供的已登录用户是否仍然处于登录中。
        /// </summary>
        /// <param name="userInfo">登录凭据</param>
        /// <returns>登录中返回True，否则返回False</returns>
        bool CheckUserLogin(LoginUserInfo userInfo);

        /// <summary>
        /// 用户是否具有某个角色
        /// </summary>
        /// <param name="userInfo">用户信息</param>
        /// <param name="roles">需要具有的角色组</param>
        /// <returns>True具有,False不具有</returns>
        bool UserInRoles(LoginUserInfo userInfo, params string[] roles);
    }
}
