﻿using JWT;
using JWT.Algorithms;
using JWT.Serializers;
using Microsoft.AspNetCore.Server.IIS.Core;
using System;
using System.Text;

namespace Falcon.SugarApi.JWT
{
    /// <summary>
    /// jwt token 生成器
    /// </summary>
    public class JwtTokenBuilder : IJwtTokenBuilder
    {
        /// <summary>
        /// 使用默认配置实例化
        /// </summary>
        public JwtTokenBuilder() : this(new JwtContext()) { }

        /// <summary>
        /// 实例化
        /// </summary>
        /// <param name="options">JWT认证配置</param>
        public JwtTokenBuilder(JwtContext options) {
            Options = options;
        }

        /// <summary>
        /// JWT认证配置
        /// </summary>
        public JwtContext Options { get; }

        /// <summary>
        /// 获取Token
        /// </summary>
        /// <param name="playload">负载</param>
        /// <returns>Token对象</returns>
        public string GetToken(LoginUserInfo playload) {
            playload = playload ?? throw new ArgumentNullException(nameof(playload));
            var key = Encoding.UTF8.GetBytes(this.Options.SecKey);
            var algorithm = new HMACSHA256Algorithm();
            var serializer = new JsonNetSerializer();
            var urlEncoder = new JwtBase64UrlEncoder();
            var encoder = new JwtEncoder(algorithm, serializer, urlEncoder);
            return encoder.Encode(playload, key);
        }

        /// <summary>
        /// 获取Token负载
        /// </summary>
        /// <param name="token">登录Token</param>
        /// <returns>负载信息</returns>
        public LoginUserInfo GetPlayload(string token) {
            var key = Encoding.UTF8.GetBytes(this.Options.SecKey);
            var serializer = new JsonNetSerializer();
            var dtProvider = new UtcDateTimeProvider();
            var validator = new JwtValidator(serializer, dtProvider);
            var urlEncoder = new JwtBase64UrlEncoder();
            var algorithm = new HMACSHA256Algorithm();
            var decoder = new JwtDecoder(serializer, validator, urlEncoder, algorithm);
            return decoder.DecodeToObject<LoginUserInfo>(token, key, true);
        }
    }
}
